#!/usr/bin/make -f
# debian/rules for the Debian xserver-xorg-driver-dove package.
# Copyright © 2004 Scott James Remnant <scott@netsplit.com>
# Copyright © 2005 Daniel Stone <daniel@fooishbar.org>
# Copyright © 2005 David Nusinow <dnusinow@debian.org>

# Uncomment this to turn on verbose mode.
#export DH_VERBOSE=1

include debian/xsfbs/xsfbs.mk

CFLAGS = -Wall -g

ifneq (,$(filter noopt,$(DEB_BUILD_OPTIONS)))
	CFLAGS += -O0
else
	CFLAGS += -O2
endif
ifneq (,$(filter parallel=%,$(DEB_BUILD_OPTIONS)))
	NUMJOBS = $(patsubst parallel=%,%,$(filter parallel=%,$(DEB_BUILD_OPTIONS)))
	MAKEFLAGS += -j$(NUMJOBS)
endif

#Add global config definitions for MRVL pacakage.

#DOVE=1, MMP2=2, TD=3
    CFLAGS += -DMRVL_SUPPORT_RANDR=1 \
              -DMRVL_SUPPORT_EXA=1 \
              -DDUMP_RAW_VIDEO=1 \
              -DMRVL_USE_OFFSCREEN_HEAP=0 \
              -DMRVL_EXA_MODE=2 \
              -DMRVL_EXA_ENABLE_UP_DOWNLOAD=0 \
              -DMRVL_EXA_FORCE_HW_LOAD=0 \
              -DMRVL_EXA_ALLOC_PIXMAP_FROM_SYSTEM=0 \
              -DMRVL_EXA_PERF_PROFILING=0 \
              -DMRVL_EXA_TRACE_FALLBACK=1 \
              -DMRVL_EXA_XBGR_SUPPORT=1 \
              -DMRVL_XV_SUPPORT_RGB_FORMAT=1 \
              -DMRVL_XV_TEX_VIDEO=0 \
              -DMRVL_XV_OVERLAY_VIDEO=1 \
              -DMRVL_XV_DEFERRED_STALL_GPU=1 \
              -DMRVL_XV_USE_FAKE_FENCE_STALL=1 \
              -DMRVL_RANDR_EDID_MODES=1 \
              -DMRVL_CRTC_SUPPORT_ROTATION=1 \
              -DMRVL_PLATFORM_INFO=1 \
              -DMRVL_SOURCE_VERSION='\"$(SOURCE_VERSION)-sw\"' \
             
              

DEB_HOST_ARCH      ?= $(shell dpkg-architecture -qDEB_HOST_ARCH)
DEB_HOST_GNU_TYPE  ?= $(shell dpkg-architecture -qDEB_HOST_GNU_TYPE)
DEB_BUILD_GNU_TYPE ?= $(shell dpkg-architecture -qDEB_BUILD_GNU_TYPE)
ifeq ($(DEB_BUILD_GNU_TYPE), $(DEB_HOST_GNU_TYPE))
	confflags += --build=$(DEB_HOST_GNU_TYPE)
else
	confflags += --build=$(DEB_BUILD_GNU_TYPE) --host=$(DEB_HOST_GNU_TYPE)
endif

# kbd_drv.a isn't phenomenally useful; kbd_drv.so more so
confflags += --disable-static

configure: $(STAMP_DIR)/patch
	dh_testdir
	autoreconf -vfi

build: build-stamp
build-stamp: configure
	dh_testdir

	test -d obj-$(DEB_BUILD_GNU_TYPE) || mkdir obj-$(DEB_BUILD_GNU_TYPE)
	cd obj-$(DEB_BUILD_GNU_TYPE) && \
	../configure --prefix=/usr --mandir=\$${prefix}/share/man \
	             --infodir=\$${prefix}/share/info $(confflags) \
	             CFLAGS="$(CFLAGS)" 
	cd obj-$(DEB_BUILD_GNU_TYPE) && $(MAKE)
	>$@

clean: xsfclean
	dh_testdir
	dh_testroot
	rm -f build-stamp

	rm -f config.cache config.log config.status
	rm -f */config.cache */config.log */config.status
	rm -f conftest* */conftest*
	rm -rf autom4te.cache */autom4te.cache
	rm -rf obj-*
	rm -f aclocal.m4 config.guess config.sub config.h.in configure
	rm -f depcomp install-sh ltmain.sh missing mkinstalldirs
	rm -f $$(find -name Makefile.in)

	dh_clean

install: build
	dh_testdir
	dh_testroot
	dh_clean -k
	dh_installdirs

	cd obj-$(DEB_BUILD_GNU_TYPE) && $(MAKE) DESTDIR=$(CURDIR)/debian/tmp install

# Build architecture-dependent files here.
binary-arch: build install serverabi
	dh_testdir
	dh_testroot

	dh_installdocs
	dh_installchangelogs ChangeLog
	dh_install --sourcedir=debian/tmp --list-missing
	dh_link
	dh_strip
	dh_compress
	dh_fixperms
	dh_installdeb
	dh_shlibdeps -- --warnings=6 --ignore-missing-info
	dh_gencontrol
	dh_md5sums
	dh_builddeb

# Build architecture-independent files here.
binary-indep: build install
# Nothing to do

binary: binary-indep binary-arch
.PHONY: build clean binary-indep binary-arch binary install
